pub type ClojureReducer = Arc<dyn Fn(&mut Cx, Value, Value) -> Result<Value> + Send + Sync + 'static>;Expand description
Reducer step used to fold sequence values during a Clojure-profile transduce.
Takes the running accumulator and the next value and returns the next accumulator.
Aliased Type
pub struct ClojureReducer { /* private fields */ }